import React, { HTMLProps, LiHTMLAttributes } from 'react';
import { Item } from './DraggableItem';
declare type Behavior = 'sort' | 'dropOutside' | 'sortAndDropOutside' | 'dropInside';
declare type CommonDragProps<T extends Item, B extends Behavior> = {
    resetButtonRef?: React.RefObject<HTMLButtonElement>;
    onReset?: (initialList: T[]) => void;
    onUndo?: (undoneList: T[]) => void;
    behavior: B;
    id: string;
    validDragComponentIds?: string[];
};
declare type DragDictionary<T extends Item, D extends Item> = {
    sort: {
        onSort: (sortedList: T[], draggedItem: T) => Promise<void> | void;
    } & CommonDragProps<T, 'sort'>;
    dropOutside: {
        onDropOutside: (draggedItem: T, dropTarget: D) => Promise<void> | void;
    } & CommonDragProps<T, 'dropOutside'>;
    sortAndDropOutside: {
        onSort: (sortedList: T[], draggedItem: T) => Promise<void> | void;
        onDropOutside: (draggedItem: T, dropTarget: D) => Promise<void> | void;
    } & CommonDragProps<T, 'sortAndDropOutside'>;
    dropInside: CommonDragProps<T, 'dropInside'>;
};
export declare type DragProps<T extends Item, D extends Item> = DragDictionary<T, D>['sort'] | DragDictionary<T, D>['dropOutside'] | DragDictionary<T, D>['sortAndDropOutside'] | DragDictionary<T, D>['dropInside'];
declare type RenderItem<T extends Item> = {
    item: T;
    index: number;
    dragRef?: React.RefObject<HTMLDivElement>;
    isOver?: boolean;
    canDrop?: boolean;
};
export declare type DragAndDropListProps<T extends Item, D extends Item> = {
    list: T[];
    renderItem: (item: RenderItem<T>) => React.ReactNode;
    dragProps?: DragProps<T, D>;
    listItemClassName?: string;
    listProps?: HTMLProps<HTMLUListElement>;
    listItemProps?: LiHTMLAttributes<HTMLLIElement>;
};
declare function DragAndDropList<T extends Item, D extends Item = Item>({ list, renderItem, dragProps, listItemClassName, listProps, listItemProps, }: DragAndDropListProps<T, D>): JSX.Element;
export default DragAndDropList;
